@@ -7,9 +7,9 @@
 
 #include "phonenumbertest.h"
 #include "kcontacts/phonenumber.h"
+#include <QTest>
 #include <addressee.h>
 #include <addresseelist.h>
-#include <QTest>
 #include <vcardtool_p.h>
 
 QTEST_MAIN(PhoneNumberTest)
@@ -45,7 +45,8 @@ void PhoneNumberTest::storeTest()
 
 void PhoneNumberTest::equalsTest()
 {
-    KContacts::PhoneNumber number1, number2;
+    KContacts::PhoneNumber number1;
+    KContacts::PhoneNumber number2;
 
     number1.setId(QStringLiteral("My Id"));
     number1.setType(KContacts::PhoneNumber::Work | KContacts::PhoneNumber::Cell);
@@ -68,7 +69,8 @@ void PhoneNumberTest::differsTest()
 
 void PhoneNumberTest::assignmentTest()
 {
-    KContacts::PhoneNumber number1, number2;
+    KContacts::PhoneNumber number1;
+    KContacts::PhoneNumber number2;
 
     number1.setId(QStringLiteral("My Id"));
     number1.setType(KContacts::PhoneNumber::Work | KContacts::PhoneNumber::Cell);
@@ -81,7 +83,8 @@ void PhoneNumberTest::assignmentTest()
 
 void PhoneNumberTest::serializeTest()
 {
-    KContacts::PhoneNumber number1, number2;
+    KContacts::PhoneNumber number1;
+    KContacts::PhoneNumber number2;
 
     number1.setId(QStringLiteral("My Id"));
     number1.setType(KContacts::PhoneNumber::Work | KContacts::PhoneNumber::Cell);
@@ -119,7 +122,7 @@ void PhoneNumberTest::labelTest()
     }
 
     // combine all with Pref
-    for (KContacts::PhoneNumber::Type type : qAsConst(types)) {
+    for (KContacts::PhoneNumber::Type type : std::as_const(types)) {
         KContacts::PhoneNumber::Type combinedType = type | KContacts::PhoneNumber::Pref;
         const KContacts::PhoneNumber phone(QLatin1String("1"), combinedType);
         QCOMPARE(phone.type(), combinedType);
@@ -135,14 +138,13 @@ void PhoneNumberTest::labelTest()
     }
 
     // combine all with Fax
-    for (KContacts::PhoneNumber::Type type : qAsConst(types)) {
+    for (KContacts::PhoneNumber::Type type : std::as_const(types)) {
         KContacts::PhoneNumber::Type combinedType = type | KContacts::PhoneNumber::Fax;
         const KContacts::PhoneNumber phone(QLatin1String("1"), combinedType);
         QCOMPARE(phone.type(), combinedType);
         QCOMPARE(KContacts::PhoneNumber::typeLabel(combinedType), phone.typeLabel());
 
-        if (type == KContacts::PhoneNumber::Home
-            || type == KContacts::PhoneNumber::Work) {
+        if (type == KContacts::PhoneNumber::Home || type == KContacts::PhoneNumber::Work) {
             // special cased
         } else if (type < KContacts::PhoneNumber::Fax) {
             const QString expectedCombinedString = QStringLiteral("%1/%2").arg(labels[type]).arg(labels[KContacts::PhoneNumber::Fax]);
@@ -155,32 +157,33 @@ void PhoneNumberTest::labelTest()
 
     // special cases
     QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Pref), QLatin1String("Preferred Number"));
-    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Home
-                                               |KContacts::PhoneNumber::Fax),
+    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Home //
+                                               | KContacts::PhoneNumber::Fax),
              QLatin1String("Home Fax"));
-    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Work
-                                               |KContacts::PhoneNumber::Fax),
+    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Work //
+                                               | KContacts::PhoneNumber::Fax),
              QLatin1String("Work Fax"));
-    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Home
-                                               |KContacts::PhoneNumber::Fax
-                                               |KContacts::PhoneNumber::Pref),
+    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Home //
+                                               | KContacts::PhoneNumber::Fax //
+                                               | KContacts::PhoneNumber::Pref),
              QLatin1String("Home Fax/Preferred"));
-    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Work
-                                               |KContacts::PhoneNumber::Fax
-                                               |KContacts::PhoneNumber::Pref),
+    QCOMPARE(KContacts::PhoneNumber::typeLabel(KContacts::PhoneNumber::Work //
+                                               | KContacts::PhoneNumber::Fax //
+                                               | KContacts::PhoneNumber::Pref),
              QLatin1String("Work Fax/Preferred"));
 }
 
 void PhoneNumberTest::shouldParseVCard21()
 {
-    QByteArray vcarddata("BEGIN:VCARD\n"
-                         "VERSION:2.1\n"
-                         "EMAIL:foo@kde.org\n"
-                         "N:;;;;\n"
-                         "TEL;CELL;WORK:+1-919-676-9564\n"
-                         "UID:testuid\n"
-                         "END:VCARD\n"
-                         "\n");
+    QByteArray vcarddata(
+        "BEGIN:VCARD\n"
+        "VERSION:2.1\n"
+        "EMAIL:foo@kde.org\n"
+        "N:;;;;\n"
+        "TEL;CELL;WORK:+1-919-676-9564\n"
+        "UID:testuid\n"
+        "END:VCARD\n"
+        "\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
@@ -209,14 +212,15 @@ void PhoneNumberTest::shouldExportVCard21()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v2_1);
-    QByteArray expected("BEGIN:VCARD\r\n"
-                        "VERSION:2.1\r\n"
-                        "EMAIL:foo@kde.org\r\n"
-                        "N:;;;;\r\n"
-                        "TEL;CELL;WORK:+1-919-676-9564\r\n"
-                        "UID:testuid\r\n"
-                        "END:VCARD\r\n"
-                        "\r\n");
+    QByteArray expected(
+        "BEGIN:VCARD\r\n"
+        "VERSION:2.1\r\n"
+        "EMAIL:foo@kde.org\r\n"
+        "N:;;;;\r\n"
+        "TEL;CELL;WORK:+1-919-676-9564\r\n"
+        "UID:testuid\r\n"
+        "END:VCARD\r\n"
+        "\r\n");
     QCOMPARE(ba, expected);
 }
 
@@ -236,14 +240,15 @@ void PhoneNumberTest::shouldExportVCard3()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v3_0);
-    QByteArray expected("BEGIN:VCARD\r\n"
-                        "VERSION:3.0\r\n"
-                        "EMAIL:foo@kde.org\r\n"
-                        "N:;;;;\r\n"
-                        "TEL;TYPE=CELL,WORK:+1-919-676-9564\r\n"
-                        "UID:testuid\r\n"
-                        "END:VCARD\r\n"
-                        "\r\n");
+    QByteArray expected(
+        "BEGIN:VCARD\r\n"
+        "VERSION:3.0\r\n"
+        "EMAIL:foo@kde.org\r\n"
+        "N:;;;;\r\n"
+        "TEL;TYPE=CELL,WORK:+1-919-676-9564\r\n"
+        "UID:testuid\r\n"
+        "END:VCARD\r\n"
+        "\r\n");
     QCOMPARE(ba, expected);
 }
 
@@ -263,30 +268,32 @@ void PhoneNumberTest::shouldExportVCard4()
     lst << addr;
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
-    QByteArray expected("BEGIN:VCARD\r\n"
-                        "VERSION:4.0\r\n"
-                        "EMAIL:foo@kde.org\r\n"
-                        "N:;;;;\r\n"
-                        "TEL;TYPE=\"cell,work\":+1-919-676-9564\r\n"
-                        "UID:testuid\r\n"
-                        "END:VCARD\r\n"
-                        "\r\n");
+    QByteArray expected(
+        "BEGIN:VCARD\r\n"
+        "VERSION:4.0\r\n"
+        "EMAIL:foo@kde.org\r\n"
+        "N:;;;;\r\n"
+        "TEL;TYPE=\"cell,work\":+1-919-676-9564\r\n"
+        "UID:testuid\r\n"
+        "END:VCARD\r\n"
+        "\r\n");
     QCOMPARE(ba, expected);
 }
 
 void PhoneNumberTest::shouldParseVcard3()
 {
-    QByteArray vcarddata("BEGIN:VCARD\n"
-                         "VERSION:3.0\n"
-                         "N:LastName;FirstName;;;\n"
-                         "TEL;VALUE=uri;PREF=1;TYPE=\"voice,home\":tel:+44-555-555-5555;ext=5555\r\n"
-                         "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
-                         "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
-                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-                         "LANG:fr\n"
-                         "REV:2015-03-14T09:24:45+00:00\n"
-                         "FN:FirstName LastName\n"
-                         "END:VCARD\n");
+    QByteArray vcarddata(
+        "BEGIN:VCARD\n"
+        "VERSION:3.0\n"
+        "N:LastName;FirstName;;;\n"
+        "TEL;VALUE=uri;PREF=1;TYPE=\"voice,home\":tel:+44-555-555-5555;ext=5555\r\n"
+        "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
+        "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
+        "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
+        "LANG:fr\n"
+        "REV:2015-03-14T09:24:45+00:00\n"
+        "FN:FirstName LastName\n"
+        "END:VCARD\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
@@ -297,17 +304,18 @@ void PhoneNumberTest::shouldParseVcard3()
 
 void PhoneNumberTest::shouldParseVcard4()
 {
-    QByteArray vcarddata("BEGIN:VCARD\n"
-                         "VERSION:4.0\n"
-                         "N:LastName;FirstName;;;\n"
-                         "TEL;VALUE=uri;PREF=1;TYPE=\"voice,home\":tel:+44-555-555-5555;ext=5555\r\n"
-                         "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
-                         "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
-                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-                         "LANG:fr\n"
-                         "REV:2015-03-14T09:24:45+00:00\n"
-                         "FN:FirstName LastName\n"
-                         "END:VCARD\n");
+    QByteArray vcarddata(
+        "BEGIN:VCARD\n"
+        "VERSION:4.0\n"
+        "N:LastName;FirstName;;;\n"
+        "TEL;VALUE=uri;PREF=1;TYPE=\"voice,home\":tel:+44-555-555-5555;ext=5555\r\n"
+        "TEL;VALUE=uri;TYPE=\"voice,cell,text\":tel:+44-555-555-6666\r\n"
+        "TEL;VALUE=uri;TYPE=\"voice,work\":tel:+44-555-555-7777\r\n"
+        "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
+        "LANG:fr\n"
+        "REV:2015-03-14T09:24:45+00:00\n"
+        "FN:FirstName LastName\n"
+        "END:VCARD\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
