@@ -60,11 +60,11 @@ namespace KContacts
   from the other name fields automatically.
 
   realName() returns a fully formatted name(). It uses formattedName, if set,
-  otherwise it constucts the name from the name fields. As fallback, if
+  otherwise it constructs the name from the name fields. As fallback, if
   nothing else is set it uses name().
 
   name() is the NAME type of RFC2426. It can be used as internal name for the
-  data enty, but shouldn't be used for displaying the data to the user.
+  data entry, but shouldn't be used for displaying the data to the user.
  */
 class KCONTACTS_EXPORT Addressee
 {
@@ -108,13 +108,14 @@ class KCONTACTS_EXPORT Addressee
     Q_PROPERTY(QString office READ office WRITE setOffice)
     Q_PROPERTY(QString profession READ profession WRITE setProfession)
     Q_PROPERTY(QString spousesName READ spousesName WRITE setSpousesName)
+    Q_PROPERTY(KContacts::Picture photo READ photo WRITE setPhoto)
 
     // using variants for QML compatibility, can be changed to proper types once QML supports that
-    Q_PROPERTY(QVariantList emails READ emailsVariant)
-    Q_PROPERTY(QVariantList phoneNumbers READ phoneNumbersVariant)
+    Q_PROPERTY(QVariantList emails READ emailsVariant WRITE setEmailsVariant)
+    Q_PROPERTY(QVariantList phoneNumbers READ phoneNumbersVariant WRITE setPhoneNumbersVariant)
     Q_PROPERTY(QVariantList addresses READ addressesVariant)
     Q_PROPERTY(QVariantList urls READ urlsVariant)
-    Q_PROPERTY(QVariantList impps READ imppsVariant)
+    Q_PROPERTY(QVariantList impps READ imppsVariant WRITE setImppsVariant)
 
     // ### the following properties are still missing:
     // - logos, photos, sounds
@@ -128,12 +129,18 @@ public:
       A list of addressee objects
      */
     typedef AddresseeList List;
+
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
     /**
       A map from unique identifier to addressee.
 
+      @deprecated Since 5.88, as it's not used anywhere.
+
       @see uid()
      */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "Deprecated, not used anywhere.")
     typedef QHash<QString, Addressee> Map;
+#endif
 
     /**
       Construct an empty address book entry.
@@ -743,6 +750,7 @@ public:
      */
     QString fullEmail(const QString &email = QString()) const;
 
+#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
     /**
       Insert an email address. If the email address already exists in this
       addressee it is not duplicated.
@@ -750,8 +758,22 @@ public:
       @param email Email address
       @param preferred Set to true, if this is the preferred email address of
                        the addressee.
+
+      @deprecated Since 5.88, use addEmail(const Email &) instead; you can use the Email
+      methods to set any parameters, e.g. Email::setPreferred(), Email::setType() ...etc
      */
+    KCONTACTS_DEPRECATED_VERSION(5, 88, "Use addEmail(const Email &), and the Email class setter methods instead.")
     void insertEmail(const QString &email, bool preferred = false, const QMap<QString, QStringList> &param = QMap<QString, QStringList>());
+#endif
+
+    /**
+      Adds an email address. If the email address (i.e. @p email.mail()) already
+      exists in this addressee it won't be duplicated, instead @p email is assigned
+      to it.
+
+      @since 5.88
+     */
+    void addEmail(const Email &email);
 
     /**
       Remove email address. If the email address doesn't exist, nothing happens.
@@ -761,8 +783,8 @@ public:
     void removeEmail(const QString &email);
 
     /**
-      Return preferred email address. This is the first email address or the
-      last one added with insertEmail() with a set preferred parameter.
+      Return preferred email address. This is the first email address or the last
+      one added with insertEmail() or addEmail() with a set preferred parameter.
      */
     QString preferredEmail() const;
 
@@ -788,7 +810,7 @@ public:
 
     /**
       Remove phone number. If no phone number with the given id exists for this
-      addresse nothing happens.
+      addressee, nothing happens.
 
       @param phoneNumber The telephone number to remove from the addressee
      */
@@ -833,7 +855,7 @@ public:
 
     /**
       Remove a key. If no key with the given id exists for this
-      addresse nothing happens.
+      addressee, nothing happens.
 
       @param key The key to remove
      */
@@ -891,7 +913,7 @@ public:
 
     /**
       Remove address. If no address with the given id exists for this
-      addresse nothing happens.
+      addressee, nothing happens.
 
       @param address The address to remove
      */
@@ -1192,10 +1214,13 @@ public:
 
 private:
     QVariantList emailsVariant() const;
+    void setEmailsVariant(const QVariantList &emails);
     QVariantList phoneNumbersVariant() const;
+    void setPhoneNumbersVariant(const QVariantList &emails);
     QVariantList addressesVariant() const;
     QVariantList urlsVariant() const;
     QVariantList imppsVariant() const;
+    void setImppsVariant(const QVariantList &impps);
 
     class Private;
     QSharedDataPointer<Private> d;
